@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-static
 version: 1.5.0.3
-id: yesod-static-1.5.0.3-71477be257ade86c1bcd703e19f5bbaa
-key: yesod_HjTFmpRtdpZGuWKRGGqCy7
+id: yesod-static-1.5.0.3-663be57bdaf5d669c0233bf144f75855
+key: yesod_CtqlnyPGHuuKRZqEmtCoPy
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -23,21 +23,21 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
-hs-libraries: HSyesod-static-1.5.0.3-HjTFmpRtdpZGuWKRGGqCy7
+hs-libraries: HSyesod-static-1.5.0.3-CtqlnyPGHuuKRZqEmtCoPy
 depends:
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
-    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
-    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
-    cryptohash-conduit-0.1.1-4ac10775feb2347dbaf7d3cc1009a7f7
-    css-text-0.1.2.1-44ac19493562c9a35faccdcd0341bb88
+    cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
+    css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
@@ -55,8 +55,8 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-app-static-3.1.4.1-208aa7b4b78ca13bfed7179fd24989e1
-    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
+    wai-app-static-3.1.4.1-44f6dcf8d731760c41ac34c914e6b5b3
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
 haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
 haddock-html: /usr/share/doc/haskell-yesod-static/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
